[pve-devel] [PATCH access-control 4/4] increase kill -9 wait to 10 seconds

Fabian Grünbichler f.gruenbichler at proxmox.com
Thu Jul 28 15:32:44 CEST 2016


---
Note: this is pretty arbitrary - but should not be longer then 30 seconds
because it is called synchronously from the GUI.

 PVE/RPCEnvironment.pm | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/PVE/RPCEnvironment.pm b/PVE/RPCEnvironment.pm
index a7e8a01..79c942d 100644
--- a/PVE/RPCEnvironment.pm
+++ b/PVE/RPCEnvironment.pm
@@ -751,8 +751,8 @@ my $kill_process_group = sub {
 
     return if !$force;
 
-    # give max 5 seconds to shut down
-    for (my $i = 0; $i < 5; $i++) {
+    # give max 10 seconds to shut down
+    for (my $i = 0; $i < 10; $i++) {
 	return if !PVE::ProcFSTools::check_process_running($pid, $pstart);
 	sleep (1);
     }
-- 
2.1.4





More information about the pve-devel mailing list